@@ -53,7 +53,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
             self.session.commit()
         except Exception as e:
             self.session.rollback()
-            raise JsonApiException({'pointer': '/data'}, "Object creation error: " + str(e))
+            raise JsonApiException("Object creation error: " + str(e), source={'pointer': '/data'})
 
         self.after_create_object(obj, data, view_kwargs)
 
@@ -67,19 +67,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
         """
         self.before_get_object(view_kwargs)
 
-        id_field = getattr(self, 'id_field', inspect(self.model).primary_key[0].key)
-        try:
-            filter_field = getattr(self.model, id_field)
-        except Exception:
-            raise Exception("{} has no attribute {}".format(self.model.__name__, id_field))
-
-        url_field = getattr(self, 'url_field', 'id')
-        filter_value = view_kwargs[url_field]
-
-        try:
-            obj = self.session.query(self.model).filter(filter_field == filter_value).one()
-        except NoResultFound:
-            obj = None
+        obj = self.retrieve_object(view_kwargs)
 
         self.after_get_object(obj, view_kwargs)
 
@@ -126,8 +114,8 @@ class SqlalchemyDataLayer(BaseDataLayer):
         if obj is None:
             url_field = getattr(self, 'url_field', 'id')
             filter_value = view_kwargs[url_field]
-            raise ObjectNotFound({'parameter': url_field},
-                                 '{}: {} not found'.format(self.model.__name__, filter_value))
+            raise ObjectNotFound('{}: {} not found'.format(self.model.__name__, filter_value),
+                                 source={'parameter': url_field})
 
         self.before_update_object(obj, data, view_kwargs)
 
@@ -142,7 +130,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
             self.session.commit()
         except Exception as e:
             self.session.rollback()
-            raise JsonApiException({'pointer': '/data'}, "Update object error: " + str(e))
+            raise JsonApiException("Update object error: " + str(e), source={'pointer': '/data'})
 
         self.after_update_object(obj, data, view_kwargs)
 
@@ -155,8 +143,8 @@ class SqlalchemyDataLayer(BaseDataLayer):
         if obj is None:
             url_field = getattr(self, 'url_field', 'id')
             filter_value = view_kwargs[url_field]
-            raise ObjectNotFound({'parameter': url_field},
-                                 '{}: {} not found'.format(self.model.__name__, filter_value))
+            raise ObjectNotFound('{}: {} not found'.format(self.model.__name__, filter_value),
+                                 source={'parameter': url_field})
 
         self.before_delete_object(obj, view_kwargs)
 
@@ -165,7 +153,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
             self.session.commit()
         except Exception as e:
             self.session.rollback()
-            raise JsonApiException('', "Delete object error: " + str(e))
+            raise JsonApiException("Delete object error: " + str(e))
 
         self.after_delete_object(obj, view_kwargs)
 
@@ -185,11 +173,11 @@ class SqlalchemyDataLayer(BaseDataLayer):
         if obj is None:
             url_field = getattr(self, 'url_field', 'id')
             filter_value = view_kwargs[url_field]
-            raise ObjectNotFound({'parameter': url_field},
-                                 '{}: {} not found'.format(self.model.__name__, filter_value))
+            raise ObjectNotFound('{}: {} not found'.format(self.model.__name__, filter_value),
+                                 source={'parameter': url_field})
 
         if not hasattr(obj, relationship_field):
-            raise RelationNotFound('', "{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
+            raise RelationNotFound("{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
 
         related_model = getattr(obj.__class__, relationship_field).property.mapper.class_
 
@@ -219,7 +207,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
             self.session.commit()
         except Exception as e:
             self.session.rollback()
-            raise JsonApiException('', "Create relationship error: " + str(e))
+            raise JsonApiException("Create relationship error: " + str(e))
 
         self.after_create_relationship(obj, updated, json_data, relationship_field, related_id_field, view_kwargs)
 
@@ -241,11 +229,11 @@ class SqlalchemyDataLayer(BaseDataLayer):
         if obj is None:
             url_field = getattr(self, 'url_field', 'id')
             filter_value = view_kwargs[url_field]
-            raise ObjectNotFound({'parameter': url_field},
-                                 '{}: {} not found'.format(self.model.__name__, filter_value))
+            raise ObjectNotFound('{}: {} not found'.format(self.model.__name__, filter_value),
+                                 source={'parameter': url_field})
 
         if not hasattr(obj, relationship_field):
-            raise RelationNotFound('', "{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
+            raise RelationNotFound("{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
 
         related_objects = getattr(obj, relationship_field)
 
@@ -277,11 +265,11 @@ class SqlalchemyDataLayer(BaseDataLayer):
         if obj is None:
             url_field = getattr(self, 'url_field', 'id')
             filter_value = view_kwargs[url_field]
-            raise ObjectNotFound({'parameter': url_field},
-                                 '{}: {} not found'.format(self.model.__name__, filter_value))
+            raise ObjectNotFound('{}: {} not found'.format(self.model.__name__, filter_value),
+                                 source={'parameter': url_field})
 
         if not hasattr(obj, relationship_field):
-            raise RelationNotFound('', "{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
+            raise RelationNotFound("{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
 
         related_model = getattr(obj.__class__, relationship_field).property.mapper.class_
 
@@ -315,7 +303,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
             self.session.commit()
         except Exception as e:
             self.session.rollback()
-            raise JsonApiException('', "Update relationship error: " + str(e))
+            raise JsonApiException("Update relationship error: " + str(e))
 
         self.after_update_relationship(obj, updated, json_data, relationship_field, related_id_field, view_kwargs)
 
@@ -336,11 +324,11 @@ class SqlalchemyDataLayer(BaseDataLayer):
         if obj is None:
             url_field = getattr(self, 'url_field', 'id')
             filter_value = view_kwargs[url_field]
-            raise ObjectNotFound({'parameter': url_field},
-                                 '{}: {} not found'.format(self.model.__name__, filter_value))
+            raise ObjectNotFound('{}: {} not found'.format(self.model.__name__, filter_value),
+                                 source={'parameter': url_field})
 
         if not hasattr(obj, relationship_field):
-            raise RelationNotFound('', "{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
+            raise RelationNotFound("{} has no attribute {}".format(obj.__class__.__name__, relationship_field))
 
         related_model = getattr(obj.__class__, relationship_field).property.mapper.class_
 
@@ -362,7 +350,7 @@ class SqlalchemyDataLayer(BaseDataLayer):
             self.session.commit()
         except Exception as e:
             self.session.rollback()
-            raise JsonApiException('', "Delete relationship error: " + str(e))
+            raise JsonApiException("Delete relationship error: " + str(e))
 
         self.after_delete_relationship(obj, updated, json_data, relationship_field, related_id_field, view_kwargs)
 
@@ -381,9 +369,9 @@ class SqlalchemyDataLayer(BaseDataLayer):
                                          .filter(getattr(related_model, related_id_field) == obj['id'])\
                                          .one()
         except NoResultFound:
-            raise RelatedObjectNotFound('', "{}.{}: {} not found".format(related_model.__name__,
-                                                                         related_id_field,
-                                                                         obj['id']))
+            raise RelatedObjectNotFound("{}.{}: {} not found".format(related_model.__name__,
+                                                                     related_id_field,
+                                                                     obj['id']))
 
         return related_object
 
@@ -486,9 +474,9 @@ class SqlalchemyDataLayer(BaseDataLayer):
                         raise InvalidInclude(str(e))
 
                     if joinload_object is None:
-                        joinload_object = joinedload(field, innerjoin=True)
+                        joinload_object = joinedload(field)
                     else:
-                        joinload_object = joinload_object.joinedload(field, innerjoin=True)
+                        joinload_object = joinload_object.joinedload(field)
 
                     related_schema_cls = get_related_schema(current_schema, obj)
 
@@ -504,12 +492,33 @@ class SqlalchemyDataLayer(BaseDataLayer):
                 except Exception as e:
                     raise InvalidInclude(str(e))
 
-                joinload_object = joinedload(field, innerjoin=True)
+                joinload_object = joinedload(field)
 
             query = query.options(joinload_object)
 
         return query
 
+    def retrieve_object(self, view_kwargs):
+        """Construct the base query to retrieve wanted object
+
+        :param dict view_kwargs: kwargs from the resource view
+        """
+        id_field = getattr(self, 'id_field', inspect(self.model).primary_key[0].key)
+        try:
+            filter_field = getattr(self.model, id_field)
+        except Exception:
+            raise Exception("{} has no attribute {}".format(self.model.__name__, id_field))
+
+        url_field = getattr(self, 'url_field', 'id')
+        filter_value = view_kwargs[url_field]
+
+        try:
+            obj = self.session.query(self.model).filter(filter_field == filter_value).one()
+        except NoResultFound:
+            obj = None
+
+        return obj
+
     def query(self, view_kwargs):
         """Construct the base query to retrieve wanted data
 
